@@ -368,7 +368,7 @@ pull_rset_attributes <- function(x) {
   att <- attributes(x)
   att_nms <- names(att)
   att_nms <- setdiff(att_nms, excl_att)
-  att$class <- setdiff(class(x), class(tibble()))
+  att$class <- setdiff(class(x), class(tibble::tibble()))
   att$class <- att$class[att$class != "rset"]
 
   lab <- try(pretty(x), silent = TRUE)
@@ -383,12 +383,21 @@ pull_rset_attributes <- function(x) {
 set_workflow <- function(workflow, control) {
   if (control$save_workflow) {
     if (!is.null(workflow$pre$actions$recipe)) {
-      rlang::inform(paste0(
-        "The workflow being saved contains a recipe, which is ",
-        format(object.size(workflow$pre$actions$recipe), units = "Mb", digits = 2),
-        " in memory. If this was not intentional, please set the control ",
-        "setting `save_workflow = FALSE`."
-      ))
+      w_size <- utils::object.size(workflow$pre$actions$recipe)
+      # make 5MB cutoff
+      if (w_size/1024^2 > 5) {
+        msg <-
+          paste0(
+            "The workflow being saved contains a recipe, which is ",
+            format(w_size, units = "Mb", digits = 2),
+            " in memory. If this was not intentional, please set the control ",
+            "setting `save_workflow = FALSE`."
+          )
+        cols <- get_tune_colors()
+        msg <- strwrap(msg, prefix = paste0(cols$symbol$info(cli::symbol$info), " "))
+        msg <- cols$message$info(paste0(msg, collapse = "\n"))
+        rlang::inform(msg)
+      }
     }
     workflow
   } else {
