@@ -1,60 +1,17 @@
 context("GP model and helpers")
-# ------------------------------------------------------------------------------
-# library(tidymodels)
-# set.seed(7898)
-# data_folds <- vfold_cv(two_class_dat, repeats = 5)
-#
-# two_class_rec <-
-#   recipe(Class ~ ., data = two_class_dat) %>%
-#   step_normalize(A, B)
-#
-# knn_model <-
-#   nearest_neighbor(
-#     mode = "classification",
-#     neighbors = tune("K"),
-#     weight_func = tune(),
-#     dist_power = tune("exponent")
-#   ) %>%
-#   set_engine("kknn")
-#
-# two_class_wflow <-
-#   workflow() %>%
-#   add_recipe(two_class_rec) %>%
-#   add_model(knn_model)
-#
-# two_class_set <-
-#   parameters(two_class_wflow) %>%
-#   update(K = neighbors(c(1, 50))) %>%
-#   update(exponent = dist_power(c(1/10, 2)))
-#
-# set.seed(2494)
-# two_class_grid <-
-#   two_class_set %>%
-#   grid_max_entropy(size = 10)
-#
-# class_metrics <- metric_set(roc_auc, accuracy, kap, mcc)
-#
-# res <- tune_grid(two_class_wflow, resamples = data_folds, grid = two_class_grid,
-#                  metrics = class_metrics, control = control_grid(verbose = TRUE))
-# saveRDS(res,
-#         file = testthat::test_path("knn_results.rds"),
-#         version = 2, compress = "xz")
-#
-# saveRDS(two_class_set,
-#         file = testthat::test_path("knn_set.rds"),
-#         version = 2, compress = "xz")
-#
-# saveRDS(two_class_grid,
-#         file = testthat::test_path("knn_grid.rds"),
-#         version = 2, compress = "xz")
+
+library(dplyr)
 
 # ------------------------------------------------------------------------------
 
 source(test_path("../helper-objects.R"))
-load(test_path("svm_results.RData"))
+svm_results <- readRDS(test_path("svm_results.rds"))
 knn_results <- readRDS(test_path("knn_results.rds"))
 knn_set <- readRDS(test_path("knn_set.rds"))
 knn_grid <- readRDS(test_path("knn_grid.rds"))
+knn_gp <- readRDS(test_path("knn_gp.rds"))
+
+svm_set <- attributes(svm_results)$parameters
 
 # ------------------------------------------------------------------------------
 
@@ -73,7 +30,6 @@ test_that('encoding before model', {
 
 test_that('GP fit - svm', {
 
-
   svm_gp <-
     tune:::fit_gp(collect_metrics(svm_results),
                   svm_set,
@@ -83,7 +39,7 @@ test_that('GP fit - svm', {
   expect_equal(class(svm_gp), "GP")
   expect_equal(
     colnames(svm_gp$X),
-    c('C', '`%^*#`', 'scale_factor')
+    c('cost', '`%^*#`', 'scale_factor')
   )
 
 })
@@ -92,13 +48,6 @@ test_that('GP fit - svm', {
 
 test_that('GP fit - knn', {
 
-  knn_gp <-
-    tune:::fit_gp(collect_metrics(knn_results),
-                  knn_set,
-                  "accuracy",
-                  control_bayes()
-    )
-
   knn_cols <- c(
     'K', 'weight_funcrectangular', 'weight_functriangular',
     'weight_funcepanechnikov', 'weight_funcbiweight',
@@ -118,7 +67,7 @@ test_that('GP scoring', {
   ctrl <- control_bayes()
   curr <-
     collect_metrics(svm_results) %>%
-    filter(.metric == "accuracy") %>%
+    dplyr::filter(.metric == "accuracy") %>%
     mutate(.iter = 0)
 
   svm_gp <-
@@ -139,7 +88,7 @@ test_that('GP scoring', {
   expect_true(tibble::is_tibble(svm_scores))
   expect_equal(
     colnames(svm_scores),
-    c('C', '%^*#', 'scale_factor', '.mean', '.sd')
+    c('cost', '%^*#', 'scale_factor', '.mean', '.sd')
   )
   expect_equal(nrow(svm_scores), 20)
 
