@@ -376,7 +376,7 @@ test_that("retain extra attributes", {
   expect_message(
     fit_resamples(
       lin_mod,
-      recipes::recipe(mpg ~ ., mtcars),
+      recipes::recipe(mpg ~ ., mtcars[rep(1:32, 3000),]),
       folds,
       control = control_resamples(save_workflow = TRUE)
     ),
